{!! view_render_event('bagisto.shop.layout.footer.before') !!}

<!--
    The category repository is injected directly here because there is no way
    to retrieve it from the view composer, as this is an anonymous component.
-->
@inject('themeCustomizationRepository', 'Webkul\Theme\Repositories\ThemeCustomizationRepository')

<!--
    This code needs to be refactored to reduce the amount of PHP in the Blade
    template as much as possible.
-->
@php
$customization = $themeCustomizationRepository->findOneWhere([
'type' => 'footer_links',
'status' => 1,
'channel_id' => core()->getCurrentChannel()->id,
]);
@endphp

<footer class="mt-9 bg-primarymain text-item  max-sm:mt-10">
    <div class="flex justify-between gap-x-6 gap-y-8 p-[60px] max-1060:flex-col-reverse max-md:gap-5 max-md:p-8 max-sm:px-4 max-sm:py-5">
        <!-- For Desktop View -->
        <div class="flex flex-wrap items-start gap-24 max-1180:gap-6 max-1060:hidden">
            @if ($customization?->options)
            @foreach ($customization->options as $footerLinkSection)
            <ul class="grid gap-5 text-sm text-white">
                @php
                usort($footerLinkSection, function ($a, $b) {
                return $a['sort_order'] - $b['sort_order'];
                });
                @endphp

                @foreach ($footerLinkSection as $link)
                <li>
                    <a href="{{ $link['url'] }}">
                        {{ $link['title'] }}
                    </a>
                </li>
                @endforeach
            </ul>
            @endforeach
            @endif
        </div>

        <!-- For Mobile view -->
        <x-shop::accordion :is-active="false" class="hidden !w-full !border-2 !border-[#e9decc] max-1060:block ">
            <x-slot:header class="rounded-t-lg bg-[#F1EADF] font-medium max-md:p-2.5 max-sm:px-3 max-sm:py-2 max-sm:text-sm">
                @lang('shop::app.components.layouts.footer.footer-content')
                </x-slot>

                <x-slot:content class="flex justify-between !bg-transparent !p-4">
                    @if ($customization?->options)
                    @foreach ($customization->options as $footerLinkSection)
                    <ul class="grid gap-5 text-sm">
                        @php
                        usort($footerLinkSection, function ($a, $b) {
                        return $a['sort_order'] - $b['sort_order'];
                        });
                        @endphp

                        @foreach ($footerLinkSection as $link)
                        <li>
                            <a href="{{ $link['url'] }}" class="text-sm font-medium max-sm:text-xs text-white">
                                {{ $link['title'] }}
                            </a>
                        </li>
                        @endforeach
                    </ul>
                    @endforeach
                    @endif
                    </x-slot>
        </x-shop::accordion>

        {!! view_render_event('bagisto.shop.layout.footer.newsletter_subscription.before') !!}

        <!-- News Letter subscription -->
        @if (core()->getConfigData('customer.settings.newsletter.subscription'))
        <div class="grid gap-2.5">
            <p class="max-w-[288px] text-3xl italic leading-[45px] text-white max-md:text-2xl max-sm:text-lg" role="heading" aria-level="2">
                @lang('shop::app.components.layouts.footer.newsletter-text')
            </p>

            <p class="text-xs text-white">
                @lang('shop::app.components.layouts.footer.subscribe-stay-touch')
            </p>

            <div>
                <x-shop::form :action="route('shop.subscription.store')" class="mt-2.5 max-sm:mt-0">
                    <div class="relative w-full">
                        <x-shop::form.control-group.control type="email" class="block w-[420px] max-w-full border-2 border-[#e9decc] bg-[#F1EADF] px-5 py-4 text-base max-1060:w-full max-md:p-3.5 max-sm:mb-0  max-sm:border-2 max-sm:p-2 max-sm:text-sm" name="email" rules="required|email" label="Email" :aria-label="trans('shop::app.components.layouts.footer.email')" placeholder="email@example.com" />

                        <x-shop::form.control-group.error control-name="email" />

                        <button type="submit" class="absolute top-1.5 flex w-max items-center bg-white px-7 py-2.5 font-medium hover:bg-zinc-100 max-md:top-1 max-md:px-5 max-md:text-xs max-sm:mt-0  max-sm:px-4 max-sm:py-2 ltr:right-2 rtl:left-2">
                            @lang('shop::app.components.layouts.footer.subscribe')
                        </button>
                    </div>
                </x-shop::form>
            </div>
        </div>
        @endif

        {!! view_render_event('bagisto.shop.layout.footer.newsletter_subscription.after') !!}
    </div>

    <div class="flex justify-between bg-primarymain px-[60px] py-3.5 max-lg:justify-center max-md:justify-center max-sm:px-5">
        {!! view_render_event('bagisto.shop.layout.footer.footer_text.before') !!}

        <p class="text-sm text-white max-md:text-center">
            @lang('shop::app.components.layouts.footer.footer-text', ['current_year'=> date('Y') ])
        </p>

        {!! view_render_event('bagisto.shop.layout.footer.footer_text.after') !!}
    </div>
</footer>

{!! view_render_event('bagisto.shop.layout.footer.after') !!}